@@ -1700,15 +1700,3 @@ class VariableClBuilderCheckAutomagicSet(Variable):
         self.label = _("Check for auto depends")
         self.help = _("check for auto depends")
 
-class VariableClBuilderCleanBdepsSet(Variable):
-    """
-    Отключить --with-bdeps при выполнении --depclean
-    """
-    type = "bool"
-    value = "off"
-
-    opt = ["--clean-bdeps"]
-
-    def init(self):
-        self.label = _("Remove packages required only for build")
-        self.help = _("remove packages required only for build")
